@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from collective.exportimport import config
+from collective.exportimport.interfaces import IMigrationMarker
 from datetime import datetime
 from DateTime import DateTime
 from plone import api
@@ -18,6 +19,7 @@ from six.moves.urllib.parse import urlparse
 from zExceptions import NotFound
 from zope.component import getMultiAdapter
 from zope.component import getUtility
+from zope.interface import alsoProvides
 from ZPublisher.HTTPRequest import FileUpload
 
 import ijson
@@ -216,6 +218,7 @@ class ImportContent(BrowserView):
 
     def do_import(self, data):
         start = datetime.now()
+        alsoProvides(self.request, IMigrationMarker)
         added = self.import_new_content(data)
         end = datetime.now()
         delta = end - start
@@ -284,7 +287,7 @@ class ImportContent(BrowserView):
 
             if not container:
                 logger.info(
-                    u"No container found for {} {}".format(item["@type"], item["@id"])
+                    u"No container (parent was {}) found for {} {}".format(item["parent"]["@type"], item["@type"], item["@id"])
                 )
                 continue
 
@@ -305,7 +308,7 @@ class ImportContent(BrowserView):
                     logger.info(u"{} ({}) already exists. Replacing it.".format(
                         new_id, item["@id"])
                     )
-                    api.content.delete(container[new_id])
+                    api.content.delete(container[new_id], check_linkintegrity=False)
 
                 elif self.handle_existing_content == 2:
                     # Update existing item
@@ -729,13 +732,13 @@ class ResetModifiedAndCreatedDate(BrowserView):
         portal = api.portal.get()
 
         def reset_dates(obj, path):
-            modified = getattr(obj, "modification_date_migrated", None)
+            modified = getattr(obj.aq_base, "modification_date_migrated", None)
             if modified and modified != obj.modification_date:
                 obj.modification_date = modified
                 del obj.modification_date_migrated
                 obj.reindexObject(idxs=["modified"])
 
-            created = getattr(obj, "creation_date_migrated", None)
+            created = getattr(obj.aq_base, "creation_date_migrated", None)
             if created and created != obj.creation_date:
                 obj.creation_date = created
                 del obj.creation_date_migrated
