@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from collective.exportimport import config
 from collective.exportimport.testing import (
     COLLECTIVE_EXPORTIMPORT_FUNCTIONAL_TESTING,  # noqa: E501,
 )
@@ -79,8 +80,13 @@ class TestExport(unittest.TestCase):
         self.assertIn("Export default pages", browser.contents)
         self.assertIn("Export object positions", browser.contents)
         # We cannot choose a portal_type, because there is no content to export.
-        with self.assertRaises(LookupError):
+        fti = self.layer['portal'].portal_types['Plone Site']
+        if "DexterityFTI" in repr(fti):
+            # In Plone 6 the portal is exportable
             browser.getControl(name="portal_type")
+        else:
+            with self.assertRaises(LookupError):
+                browser.getControl(name="portal_type")
 
     def test_export_content_document(self):
         # First create some content.
@@ -321,6 +327,28 @@ class TestExport(unittest.TestCase):
             [{"default_page": "doc1", "uuid": folder1.UID()}],
         )
 
+    def test_export_defaultpage_for_site(self):
+        # First create some content.
+        app = self.layer["app"]
+        portal = self.layer["portal"]
+        login(app, SITE_OWNER_NAME)
+        api.content.create(
+            container=portal, type="Document", id="doc1", title="Document 1"
+        )
+        portal._setProperty("default_page", "doc1")
+        transaction.commit()
+
+        browser = self.open_page("@@export_defaultpages")
+        browser.getForm(action="@@export_defaultpages").submit(name="form.submitted")
+        contents = browser.contents
+        if not browser.contents:
+            contents = DATA[-1]
+        data = json.loads(contents)
+        self.assertListEqual(
+            data,
+            [{"default_page": "doc1", "uuid": config.SITE_ROOT}],
+        )
+
     def test_export_ordering(self):
         # First create some content.
         app = self.layer["app"]
